@@ -1,19 +1,7 @@
 
 
-import extruct
-from w3lib.html import get_base_url
-
-from ioc_finder import find_iocs
-from bs4 import BeautifulSoup
-import requests
-import urllib.parse
-from urllib.parse import urlparse
-import html2text
-import pprint
-pp = pprint.PrettyPrinter(indent=4)
 from boilerpy3 import extractors
 import re
-import json
 
 
 def get(url, html):
